from datetime import datetime
from typing import List, Optional, Dict, Any

from janis_core import *
from janis_core.types.common_data_types import File, Int, Boolean, String, Array

Hicaggregatecontacts_V0_1_0 = CommandToolBuilder(tool="hicAggregateContacts", base_command=["hicAggregateContacts"], inputs=[ToolInput(tag="in_matrix", input_type=File(optional=True), prefix="--matrix", doc=InputDocumentation(doc="Path of the Hi-C matrix to plot.")), ToolInput(tag="in_out_filename", input_type=File(optional=True), prefix="--outFileName", doc=InputDocumentation(doc="File name to save the image.")), ToolInput(tag="in_bed", input_type=File(optional=True), prefix="--BED", doc=InputDocumentation(doc="Interactions between regions in this BED file are")), ToolInput(tag="in_bed_two", input_type=Int(optional=True), prefix="--BED2", doc=InputDocumentation(doc="Optional second BED file. Interactions between regions\nin first and second BED file are plotted.")), ToolInput(tag="in_number_of_bins", input_type=Int(optional=True), prefix="--numberOfBins", doc=InputDocumentation(doc="Number of bins to include in the submatrix. The bed\nregions will be centered between half number of bins\nand the other half number of bins.")), ToolInput(tag="in_transform", input_type=Boolean(optional=True), prefix="--transform", doc=InputDocumentation(doc="{total-counts,z-score,obs/exp,none}\nType of transformation for the matrix. The options are\n'none', 'total-counts', 'z-score' and 'obs/exp'. If\ntotal counts are selected, the sub-matrix values are\ndivided by the total counts for normalization. If\nz-score or obs/exp are selected, the Hi-C matrix is\nconverted into a z-score or observed / expected\nmatrix.")), ToolInput(tag="in_avg_type", input_type=String(optional=True), prefix="--avgType", doc=InputDocumentation(doc="Type of average used in the output matrix. Options are\nmean and median. Default is median.")), ToolInput(tag="in_dpi", input_type=String(optional=True), prefix="--dpi", doc=InputDocumentation(doc="Optional parameter: Resolution for the image in case\ntheoutput is a raster graphics image (e.g png, jpg).")), ToolInput(tag="in_outfile_prefix_matrix", input_type=File(optional=True), prefix="--outFilePrefixMatrix", doc=InputDocumentation(doc="If this option is set, the values underlying the\noutput matrix will be saved to tab-delimited tables\n(one per chromosome) using the indicated prefix, for\nexample TSS_to_TSS_chrX.tab. If clustering is\nperformed, the values are saved including the\ncluster_id in the file TSS_to_TSS_chrX_cluster_1.tab.")), ToolInput(tag="in_outfile_contact_pairs", input_type=File(optional=True), prefix="--outFileContactPairs", doc=InputDocumentation(doc="Output file prefix. If this option is set, the\nposition of the contact positions are saved as\n(chrom1, start1, end1, chrom2, start2, end2) where\nchrom_n, start_n, end_n correspond to the pair of\npositions used to compute the submatrix. The data is\nsaved per chromosome and per cluster separately (one\nfile each). The format is\n{prefix}_{chrom}_{cluster_id}.tab. If no clusters were\ncomputed, then only one file per chromosome is\nproduced.")), ToolInput(tag="in_diagnostic_heat_map_file", input_type=File(optional=True), prefix="--diagnosticHeatmapFile", doc=InputDocumentation(doc="If given, a heatmap (per chromosome) is saved. Each\nrow in the heatmap contains thediagonal of each of the\nsubmatrices centered on the bed file. This file is\nuseful to get an idea of the values that are used for\nthe aggregate matrix and to determine the fraction of\nsub-matrices that are aggregated that may have an\nenrichment at the center.")), ToolInput(tag="in_row_wise", input_type=Boolean(optional=True), prefix="--row_wise", doc=InputDocumentation(doc="If given,the insteractions between each row of the BED\nfile and its corresponding row of the BED2 file are\ncomputed.")), ToolInput(tag="in_k_means", input_type=Int(optional=True), prefix="--kmeans", doc=InputDocumentation(doc="Number of clusters to compute. When this option is\nset, the submatrices are split into clusters (per\nchromosome) using the k-means algorithm.")), ToolInput(tag="in_hc_lust", input_type=Int(optional=True), prefix="--hclust", doc=InputDocumentation(doc="Number of clusters to compute (per chromosome). When\nthis option is set, the matrix is split into clusters\nusing the hierarchical clustering algorithm, using\n'ward linkage'. --hclust could be very slow if you\nhave >1000 submatrices per chromosome. In those cases,\nyou might prefer --kmeans")), ToolInput(tag="in_how_to_cluster", input_type=String(optional=True), prefix="--howToCluster", doc=InputDocumentation(doc="Options are 'full', 'center' and 'diagonal'. The full\nclustering is the default and takes all values of each\nsubmatrix for clustering. 'center', takes only a\nsquare of length 3x3 from each submatrix and uses only\nthis values for clustering. With the 'diagonal' option\nthe clustering is only carried out based on the\nsubmatrix diagonal (representing values at the same\ndistance to each other.)")), ToolInput(tag="in_chromosomes", input_type=Array(t=String(), optional=True), prefix="--chromosomes", doc=InputDocumentation(doc="List of chromosomes to plot.")), ToolInput(tag="in_colormap", input_type=String(optional=True), prefix="--colorMap", doc=InputDocumentation(doc="Color map to use for the heatmap. Available values can\nbe seen here: http://matplotlib.org/examples/color/col\normaps_reference.html")), ToolInput(tag="in_plot_type", input_type=String(optional=True), prefix="--plotType", doc=InputDocumentation(doc="Plot type.")), ToolInput(tag="in_vmin", input_type=String(optional=True), prefix="--vMin", doc=InputDocumentation(doc="Minimum value of the plotted score.")), ToolInput(tag="in_vmax", input_type=String(optional=True), prefix="--vMax", doc=InputDocumentation(doc="Maximum value of the plotted score.")), ToolInput(tag="in_plotted_dot", input_type=String(), position=0, doc=InputDocumentation(doc="--range RANGE         Range of contacts that will be considered for plotting"))], outputs=[ToolOutput(tag="out_out_filename", output_type=File(optional=True), selector=InputSelector(input_to_select="in_out_filename", type_hint=File()), doc=OutputDocumentation(doc="File name to save the image.")), ToolOutput(tag="out_outfile_prefix_matrix", output_type=File(optional=True), selector=InputSelector(input_to_select="in_outfile_prefix_matrix", type_hint=File()), doc=OutputDocumentation(doc="If this option is set, the values underlying the\noutput matrix will be saved to tab-delimited tables\n(one per chromosome) using the indicated prefix, for\nexample TSS_to_TSS_chrX.tab. If clustering is\nperformed, the values are saved including the\ncluster_id in the file TSS_to_TSS_chrX_cluster_1.tab.")), ToolOutput(tag="out_outfile_contact_pairs", output_type=File(optional=True), selector=InputSelector(input_to_select="in_outfile_contact_pairs", type_hint=File()), doc=OutputDocumentation(doc="Output file prefix. If this option is set, the\nposition of the contact positions are saved as\n(chrom1, start1, end1, chrom2, start2, end2) where\nchrom_n, start_n, end_n correspond to the pair of\npositions used to compute the submatrix. The data is\nsaved per chromosome and per cluster separately (one\nfile each). The format is\n{prefix}_{chrom}_{cluster_id}.tab. If no clusters were\ncomputed, then only one file per chromosome is\nproduced."))], container=None, version="v0.1.0")


if __name__ == "__main__":
    # or "cwl"
    Hicaggregatecontacts_V0_1_0().translate("wdl", allow_empty_container=True)

